searchData={"items":[{"type":"module","title":"Hydrex","doc":"Hydrex provides automatic hydration of virtual fields in your Ecto models.\nBy deriving the `Hydrex.Hydratable` protocol and defining resolver functions for your virtual fields,\nyou can easily populate these fields when querying your models.\n\nTo use Hydrex, define virtual fields in your Ecto schema and implement resolver functions with matching names.\nThen, derive your schema with `Hydrex.Hydratable`.\n\nUse `Hydrex.Hydratable.Utils.maybe_hydrate/2` to control hydration when fetching records.","ref":"Hydrex.html"},{"type":"module","title":"Examples - Hydrex","doc":"Here's how you can use Hydrex to hydrate virtual fields in your Ecto schemas:\n\n    defmodule MyApp.Url do\n      use Ecto.Schema\n\n      @derive {Hydrex.Hydratable, []}\n      schema \"urls\" do\n        field :link, :string\n        field :title, :string\n        field :is_safe, :boolean, virtual: true\n      end\n\n      def is_safe(url) do\n        String.starts_with?(url.link, \"https://\")\n      end\n    end\n\nWhen querying your models, you can choose to hydrate the virtual fields:\n\n    import Hydrex.Hydratable.Utils, only: [maybe_hydrate: 2]\n    Repo.all(MyApp.Url) |> maybe_hydrate(hydrate: true)\n    # or\n    Repo.all(MyApp.Url) |> maybe_hydrate(true)\n\n\nSee the documentation for installation and usage details.","ref":"Hydrex.html#module-examples"},{"type":"protocol","title":"Hydrex.Hydratable","doc":"","ref":"Hydrex.Hydratable.html"},{"type":"function","title":"Hydrex.Hydratable.hydrate/1","doc":"Hydrates an Ecto struct or a list of structs.","ref":"Hydrex.Hydratable.html#hydrate/1"},{"type":"type","title":"Hydrex.Hydratable.t/0","doc":"All the types that implement this protocol.","ref":"Hydrex.Hydratable.html#t:t/0"},{"type":"module","title":"Hydrex.Hydratable.Utils","doc":"","ref":"Hydrex.Hydratable.Utils.html"},{"type":"function","title":"Hydrex.Hydratable.Utils.maybe_hydrate/2","doc":"Conditionally hydrates the given data.\n\nIf the second argument is a boolean, hydration is performed if it's `true`.\nIf the second argument is a keyword list, hydration is performed if `:hydrate` is `true` in the options.","ref":"Hydrex.Hydratable.Utils.html#maybe_hydrate/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}